@@ -1,7 +1,7 @@
 import os
 import json
 
-import pytest
+from cpg_utils.config import get_config, set_config_paths
 from cpg_utils.deploy_config import (
     DEFAULT_CONFIG,
     DeployConfig,
@@ -30,9 +30,6 @@ def test_env_config(monkeypatch, json_load):
 
 def test_env_override_config(monkeypatch):
     monkeypatch.delenv("CPG_DEPLOY_CONFIG", raising=False)
-    monkeypatch.setenv("CLOUD", "bogus")
-    with pytest.raises(AssertionError, match="Invalid cloud specification"):
-        dc = DeployConfig.from_environment()
     monkeypatch.setenv("CLOUD", "azure")
     dc = DeployConfig.from_environment()
     assert dc.cloud == "azure"
@@ -44,8 +41,10 @@ def test_config_from_dict(json_load):
     assert dc.to_dict() == cfg1
 
 
-def test_config_from_partial_dict(json_load):
+def test_config_from_toml(test_resources_path, json_load):
+    set_config_paths([os.path.join(test_resources_path, "config_01.toml")])
+    get_config()
+
     cfg1 = json_load("config_01.json")
-    del cfg1["cloud"]
-    with pytest.raises(TypeError, match="missing 1 required positional argument: 'cloud'"):
-        dc = DeployConfig.from_dict(cfg1)
+    dc = get_deploy_config()
+    assert dc.to_dict() == cfg1
